NAME = "数据(Data)"

ID = "orange.widgets.data"

DESCRIPTION = """数据处理的部件."""

LONG_DESRIPTION = """
此目录包含用于数据操作的部件: 加载，导入，保存，预处理，选择等.

"""

ICON = "icons/Category-Data.svg"

BACKGROUND = "#FFD39F"

PRIORITY = 1
